==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PointSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeries, _super);
    function PointSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PointSeries.$;
        return _this;
    }
    PointSeries.prototype.get_dx = function () {
        return true;
    };
    PointSeries.prototype.cg = function () {
        return new PointSeriesView(this);
    };
    PointSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.ze = a;
    };
    PointSeries.prototype.iq = function () {
        return 0.7;
    };
    PointSeries.prototype.t4 = function () {
        if (this.t3 == 0) {
            return 2;
        }
        return _super.prototype.t4.call(this);
    };
    PointSeries.prototype.f4 = function (a, b) {
        var c = this.th(this.tm(a), true, false);
        if (this.ud(a, b)) {
            return true;
        }
        return false;
    };
    PointSeries.prototype.o8 = function (a, b, c, d) {
        _super.prototype.o8.call(this, a, b, c, d);
    };
    Object.defineProperty(PointSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
}(HorizontalAnchoredCategorySeries));
export { PointSeries };
/**
 * @hidden
 */
var PointSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeriesView, _super);
    function PointSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dd = null;
        _this.dd = a;
        return _this;
    }
    PointSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.ua = Defaults.e;
        }
    };
    PointSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.s6 = a;
        this.e.ir = 3;
        this.e.is = 2;
        this.e.it = 2;
        this.e.gj = false;
    };
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
}(AnchoredCategorySeriesView));
export { PointSeriesView };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core";
import { List$1 } from "igniteui-react-core";
import { ChartSelection } from "./ChartSelection";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var PointSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeries, _super);
    function PointSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PointSeries.$;
        return _this;
    }
    PointSeries.prototype.bj = function () {
        return new PointSeries();
    };
    PointSeries.prototype.get_eh = function () {
        return true;
    };
    PointSeries.prototype.cr = function () {
        return new PointSeriesView(this);
    };
    PointSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.acr = a;
    };
    PointSeries.prototype.jk = function () {
        return 0.7;
    };
    PointSeries.prototype.ww = function () {
        if (this.wv == 0) {
            return 2;
        }
        return _super.prototype.ww.call(this);
    };
    PointSeries.prototype.gv = function (a, b) {
        var c = this.v8(this.wd(a), true, false);
        if (this.xc(a, b)) {
            return true;
        }
        return false;
    };
    PointSeries.prototype.q7 = function (a, b, c, d) {
        _super.prototype.q7.call(this, a, b, c, d);
    };
    PointSeries.prototype.p1 = function (a, b, c) {
        this.z7(a, b, c, this.yo, 0);
    };
    PointSeries.prototype.ak = function (a, b) {
        var c = new List$1(ChartSelection.$, 0);
        this.p1(a, c, b);
        return c.toArray();
    };
    Object.defineProperty(PointSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zl;
        },
        enumerable: false,
        configurable: true
    });
    PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
    return PointSeries;
}(HorizontalAnchoredCategorySeries));
export { PointSeries };
/**
 * @hidden
 */
var PointSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PointSeriesView, _super);
    function PointSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.df = null;
        _this.df = a;
        return _this;
    }
    PointSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w5 = Defaults.e;
        }
    };
    PointSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vx = a;
        this.e.jl = 3;
        this.e.jm = 2;
        this.e.jn = 2;
        this.e.hb = false;
    };
    PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
    return PointSeriesView;
}(AnchoredCategorySeriesView));
export { PointSeriesView };
